Reitit routing integration for Relm applications.
Provides seamless integration between Metosin's Reitit library and Relm:
:contextpopstate listeners managed through Relm side effectscurrent-route, current-view, current-match, path-for)update message handlers for navigation (::navigate-to, ::replace-to, ::route-changed, ::start, ::stop, etc.)Reitit routing integration for Relm applications. Provides seamless integration between Metosin's Reitit library and Relm: - Automatic synchronization of the current route match inside Relm's global `:context` - Browser HTML5 history integration via `popstate` listeners managed through Relm side effects - Helper functions for querying routes and views from the context (`current-route`, `current-view`, `current-match`, `path-for`) - Declarative Relm `update` message handlers for navigation (`::navigate-to`, `::replace-to`, `::route-changed`, `::start`, `::stop`, etc.)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |